#!/bin/bash
PRODUCTNAME="radmin"
TMPDIR="/tmp/radmin"
INSTALLDIR="/usr/local"
IPCDIR="/etc/ipconnect"
OLDVERSION=-1
NEWVERSION=-1
MAJORVERSION=1

mkdir -p "$TMPDIR"
mkdir -p "$IPCDIR"

if [ -e "$IPCDIR/$PRODUCTNAME.ver" ]
then
    OLDVERSION=$(cat "$IPCDIR/$PRODUCTNAME.ver" |cut -d"." -f2)
fi
NEWVERSION=$(head -n 1 "$INSTALLDIR/$PRODUCTNAME/version.txt" |cut -d"." -f2)
echo "-- Updating from $MAJORVERSION.$OLDVERSION to $MAJORVERSION.$NEWVERSION"

#On va faire une boucle à partir de "ancienne version + 1" jusqu'a la derniere version incluse
i=$(($OLDVERSION+1))
if [ $OLDVERSION -eq $NEWVERSION ]
then
	i=$OLDVERSION;
	echo "-- Updating same version but different revision, reexecuting patch of $i"
fi

while [ $i -le $NEWVERSION ]
do
    echo "-- Executing patch $MAJORVERSION.$i"
    find "$INSTALLDIR/$PRODUCTNAME/InstallScripts/$MAJORVERSION.$i" -name '*' -exec dos2unix {} 2> /dev/null \;
    bash "$INSTALLDIR/$PRODUCTNAME/InstallScripts/$MAJORVERSION.$i/update.sh"
    i=$(($i+1))
done

#Restore les fichiers de config
if [ -e "$IPCDIR/config_client.php.old" ]
then
    echo "-- Restoring configuration"
    mv -f "$IPCDIR/config_client.php.old" "$INSTALLDIR/$PRODUCTNAME/config_client.php"
fi

SYSTEMCTL=0
if [ -f /usr/bin/systemctl ]
then
    SYSTEMCTL=1
fi
if [ -f /bin/systemd ]
then
    SYSTEMCTL=1
fi
if [ -f /usr/bin/systemd ]
then
    SYSTEMCTL=1
fi

if [ $SYSTEMCTL -eq 1 ]
then
    #CPBX 5
    systemctl daemon-reload
    systemctl enable radmin
    systemctl restart radmin
else
    chkconfig radmin on
    service radmin restart
fi

echo "$MAJORVERSION.$NEWVERSION" > "$IPCDIR/$PRODUCTNAME.ver"
echo "-- Update finished"

rm -rf "$TMPDIR"
exit